@@ -1,7 +1,7 @@
-from dataclasses import dataclass
 from dataclasses import field as dataclass_field
 from typing import Optional
 
+from pydantic.dataclasses import dataclass
 from serde import deserialize
 
 from metaphor.common.base_config import BaseConfig
